### Name: uc.forecast
### Title: Forecast density estimation unconditional forecasts for
###   VAR/BVAR/BSVAR models via MCMC
### Aliases: uc.forecast uc.forecast.VAR uc.forecast.BVAR
### Keywords: ts models

### ** Examples

## Not run: 
##D ## Uses the example from Brandt and Freeman 2006.  Will not run unless
##D ## you have their data from http://yule.utdallas.edu or the Politcal
##D ## Analysis website!
##D library(MSBVAR)   # Brandt's package for Bayesian VAR models
##D 
##D # Read the data and set up as a time series
##D data <- read.dta("levant.weekly.79-03.dta") 
##D attach(data)
##D 
##D # Set up KEDS data
##D KEDS.data <- ts(cbind(a2i,a2p,i2a,p2a,i2p,p2i),
##D                 start=c(1979,15),
##D                 freq=52,
##D                 names=c("A2I","A2P","I2A","P2A","I2P","P2I"))
##D 
##D # Select the sample we want to use.
##D KEDS <- window(KEDS.data, end=c(1988,50))
##D 
##D ################################################################################
##D # Estimate the BVAR models 
##D ################################################################################
##D 
##D # Fit a flat prior model
##D KEDS.BVAR.flat <- szbvar(KEDS, p=6, z=NULL, lambda0=1,
##D                          lambda1=1, lambda3=1, lambda4=1, lambda5=0,
##D                          mu5=0, mu6=0, nu=0, qm=4, prior=2,
##D                          posterior.fit=F)
##D 
##D # Reference prior model -- Normal-IW prior pdf
##D KEDS.BVAR.informed <- szbvar(KEDS, p=6, z=NULL, lambda0=0.6,
##D                              lambda1=0.1, lambda3=2, lambda4=0.5, lambda5=0,
##D                              mu5=0, mu6=0, nu=ncol(KEDS)+1, qm=4, prior=0,
##D                              posterior.fit=F)
##D 
##D # Set up conditional forecast matrix conditions
##D nsteps <- 12
##D a2i.condition <- rep(mean(KEDS[,1]) + sqrt(var(KEDS[,1])) , nsteps)
##D 
##D yhat<-matrix(c(a2i.condition,rep(0, nsteps*5)), ncol=6)
##D 
##D # Set the random number seed so we can replicate the results.
##D set.seed(11023)
##D 
##D # Conditional forecasts
##D conditional.forcs.ref <- hc.forecast(KEDS.BVAR.informed, yhat, nsteps,
##D                             burnin=3000, gibbs=5000, exog=NULL)
##D 
##D conditional.forcs.flat <- hc.forecast(KEDS.BVAR.flat, yhat, nsteps,
##D                              burnin=3000, gibbs=5000, exog=NULL)
##D 
##D # Unconditional forecasts
##D unconditional.forcs.ref <-uc.forecast(KEDS.BVAR.informed, nsteps,
##D                                           burnin=3000, gibbs=5000)
##D 
##D unconditional.forcs.flat <- uc.forecast(KEDS.BVAR.flat, nsteps,
##D                                             burnin=3000, gibbs=5000)
##D 
##D # Set-up and plot the unconditional and conditional forecasts.  This
##D # code pulls for the forecasts for I2P and P2I and puts them into the
##D # appropriate array for the figures we want to generate.
##D uc.flat <- NULL
##D hc.flat <- NULL
##D uc.ref <- NULL
##D hc.ref <- NULL
##D 
##D uc.flat$forecast <- unconditional.forcs.flat$forecast[,,5:6]
##D hc.flat$forecast <- conditional.forcs.flat$forecast[,,5:6]
##D uc.ref$forecast <- unconditional.forcs.ref$forecast[,,5:6]
##D hc.ref$forecast <- conditional.forcs.ref$forecast[,,5:6]
##D 
##D par(mfrow=c(2,2), omi=c(0.25,0.5,0.25,0.25)) 
##D plot(uc.flat,hc.flat, probs=c(0.16, 0.84), varnames=c("I2P", "P2I"),
##D      compare.level=KEDS[nrow(KEDS),5:6], lwd=2)
##D plot(hc.ref,hc.flat, probs=c(0.16, 0.84), varnames=c("I2P", "P2I"),
##D      compare.level=KEDS[nrow(KEDS),5:6], lwd=2)
##D 
## End(Not run)




